<?php

declare(strict_types=1);

namespace Drupal\file_defaults_by_type;

use Drupal\field\FieldConfigInterface;

/**
 * An interface for a manager to handle fields where default files are enabled.
 */
interface DefaultFilesFieldManagerInterface {

  /**
   * Flag to indicate that a field configuration is valid.
   */
  public const FIELD_CONFIG_OK = 0;

  /**
   * Flag to indicate that a field configuration is missing file entities.
   */
  public const FIELD_CONFIG_MISSING_FILES = 1;

  /**
   * Flag to indicate that a field configuration is in a broken state.
   *
   * A broken state is when e.g. a type title is present but no default file
   * has been specified (so no UUID).
   */
  public const FIELD_CONFIG_BROKEN = 2;

  /**
   * Flag to indicate that a field configuration has file validation errors.
   *
   * This occurs when e.g. the file extension is wrong for at least one of
   * the currently uploaded files.
   */
  public const FIELD_CONFIG_FILE_VALIDATION_FAILED = 3;

  /**
   * Retrieves the fields where the default file types are enabled.
   *
   * This method does not filter on configuration validity.
   *
   * @return \Drupal\field\FieldConfigInterface[]
   *   The fields.
   */
  public function getEnabledFields(): array;

  /**
   * Returns the configuration status for a field.
   *
   * @param \Drupal\field\FieldConfigInterface $field
   *   The field config entity.
   *
   * @return int
   *   Returns a flag indicating the status.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   *   Thrown when a field where default file types are not enabled.
   */
  public function getFieldConfigurationStatus(FieldConfigInterface $field): int;

}
