<?php

namespace Drupal\file_defaults_by_type;

/**
 * Provides helpers to manage types in file fields.
 */
class FileTypesHelper {

  /**
   * Method to check if an array of settings has necessary keys for file types.
   *
   * @param array $settings
   *   The array of settings.
   *
   * @return bool
   *   If file defaults is enabled
   */
  public static function isEnabled(array $settings): bool {
    return !empty($settings['enabled']) && !empty($settings['types']);
  }

  /**
   * Method to retrieve valid types from an array of settings.
   *
   * @param array $settings
   *   The array of settings.
   *
   * @return array
   *   Types that match requirements.
   */
  public static function getValidTypes(array $settings): array {
    $valid_types = [];

    foreach ($settings['types'] as $type) {
      if (!empty($type['label']) && !empty($type['default'])) {
        $valid_types[] = $type;
      }
    }
    return $valid_types;
  }

}
