<?php

declare(strict_types=1);

namespace Drupal\Tests\file_defaults_by_type\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\Tests\file\Functional\FileFieldCreationTrait;
use Drupal\Tests\file_defaults_by_type\Traits\TestsFilesTrait;
use Drupal\field\Entity\FieldConfig;

/**
 * Base test class for file defaults file.
 */
abstract class FieldTestBase extends WebDriverTestBase {

  use FileFieldCreationTrait;
  use TestsFilesTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'file_defaults_by_type',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with permission to administer the site.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->drupalCreateContentType(['type' => 'article', 'name' => 'Article']);
    $this->adminUser = $this->drupalCreateUser([
      'access content',
      'access administration pages',
      'administer nodes',
      'bypass node access',
      'administer site configuration',
    ]);
    $this->drupalLogin($this->adminUser);

    // Create file field with some types.
    $this->createFileField(
      'test_file_field',
      'node',
      'article',
      [
        'cardinality' => 1,
      ],
      [
        'file_directory' => '',
      ]
    );

    $this->generateTestFiles();
    $settings = [
      'enabled' => TRUE,
      'types' => [
        [
          'label' => 'File 1',
          'default' => 'uuid-1',
        ],
        [
          'label' => 'File 2',
          'default' => 'uuid-2',
        ],
        [
          'label' => 'File 3',
          'default' => 'uuid-3',
        ],
      ],
    ];

    foreach ($settings as $k => $v) {
      FieldConfig::load('node.article.test_file_field')
        ->setThirdPartySetting('file_defaults_by_type', $k, $v)->save();
    }

    // Change widget to use the default files.
    \Drupal::service('entity_display.repository')->getFormDisplay('node', 'article')
      ->setComponent('test_file_field', ['type' => 'default_file_choice'])
      ->save();
  }

}
