<?php

declare(strict_types=1);

namespace Drupal\Tests\file_defaults_by_type\Traits;

use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\field\FieldConfigInterface;

/**
 * Provides method for generating test files.
 */
trait DefaultFilesFieldTrait {

  /**
   * Creates a field with specific settings for default fields.
   *
   * @param string $name
   *   The name of the new field (all lowercase). The Field UI 'field_' prefix
   *   is not added to the field name.
   * @param string $entity_type
   *   The entity type.
   * @param string $bundle
   *   The bundle that this field will be added to.
   * @param array $storage_settings
   *   A list of field storage settings that will be added to the defaults.
   * @param array $field_settings
   *   A list of instance settings that will be added to the instance defaults.
   * @param array $third_party_settings
   *   Settings used for file_defaults_by_type.
   *
   * @return \Drupal\field\FieldConfigInterface
   *   The created field.
   */
  protected function createDefaultFilesField(string $name, string $entity_type, string $bundle, array $storage_settings = [], array $field_settings = [], array $third_party_settings = []): FieldConfigInterface {
    FieldStorageConfig::create([
      'field_name' => $name,
      'entity_type' => $entity_type,
    ] + $storage_settings)->save();

    $field_config = FieldConfig::create([
      'field_name' => $name,
      'entity_type' => $entity_type,
      'bundle' => $bundle,
    ] + $field_settings);

    $field_config->save();

    foreach ($third_party_settings as $k => $v) {
      $field_config->setThirdPartySetting('file_defaults_by_type', $k, $v)->save();
    }

    return $field_config;
  }

}
