<?php

declare(strict_types=1);

namespace Drupal\Tests\file_defaults_by_type\Traits;

use Drupal\file\Entity\File;

/**
 * Provides method for generating test files.
 */
trait TestsFilesTrait {

  /**
   * Creates a specific number of text files.
   *
   * @param int $count
   *   The number of files to create.
   */
  protected function generateTestFiles($count = 3): void {
    for ($i = 1; $i <= $count; $i++) {
      $this->generateTestFile($i);
    }
    // Check that existing files are only generated.
    // @todo What is this for?
    $this->assertFilesCount($count);
  }

  /**
   * Creates a single test file.
   *
   * File data is based on the counter ($i):
   *  - uuid: uuid-$i
   *  - uri: public://example-$i.txt
   *  - name: example-$i.txt.
   *
   * @param int|null $counter
   *   A counter to be used in file data.
   */
  protected function generateTestFile(?int $counter = 1): void {
    file_put_contents("public://example-{$counter}.txt", $this->randomMachineName());
    $file = File::create([
      'uuid' => "uuid-$counter",
      'uri' => "public://example-$counter.txt",
      'name' => "example-$counter.txt",
      'status' => 1,
    ]);
    $file->save();
  }

  /**
   * Asserts how many file entities exist.
   *
   * @param int $count
   *   The expected number of entities.
   */
  protected function assertFilesCount(int $count): void {
    $this->assertCount($count, \Drupal::entityTypeManager()->getStorage('file')->loadMultiple());
  }

}
